/*
 * Copyright (c) 2013-2019 Huawei Technologies Co., Ltd. All rights reserved.
 * Copyright (c) 2020-2021 Huawei Device Co., Ltd. All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without modification,
 * are permitted provided that the following conditions are met:
 *
 * 1. Redistributions of source code must retain the above copyright notice, this list of
 * conditions and the following disclaimer.
 *
 * 2. Redistributions in binary form must reproduce the above copyright notice, this list
 * of conditions and the following disclaimer in the documentation and/or other materials
 * provided with the distribution.
 *
 * 3. Neither the name of the copyright holder nor the names of its contributors may be used
 * to endorse or promote products derived from this software without specific prior written
 * permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
 * "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO,
 * THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR
 * PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDER OR
 * CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL,
 * EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
 * PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS;
 * OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY,
 * WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR
 * OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF
 * ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */
#ifndef _IT_PTHREAD_TEST_H  // 防止头文件被重复包含
#define _IT_PTHREAD_TEST_H
 
#include "osTest.h"  // 包含操作系统测试相关的头文件
#include <sys/resource.h>  // 包含资源控制相关的头文件
#include <sys/wait.h>  // 包含等待进程结束相关的头文件
#include <time.h>  // 包含时间处理的头文件
 
#define SLEEP_AND_YIELD(tick) usleep((tick)*10 * 1000)  // 定义宏，用于睡眠和让出CPU，tick为微秒单位
 
#include "sys/syscall.h"  // 包含系统调用相关的头文件
 
// 定义一个内联函数，用于执行系统调用
static inline int Syscall(int nbr, int parm1, int parm2, int parm3, int parm4)
{
    register int reg7 __asm__("r7") = nbr;  // 将系统调用号放入寄存器r7
    register int reg3 __asm__("r3") = parm4;  // 将第四个参数放入寄存器r3
    register int reg2 __asm__("r2") = parm3;  // 将第三个参数放入寄存器r2
    register int reg1 __asm__("r1") = parm2;  // 将第二个参数放入寄存器r1
    register int reg0 __asm__("r0") = parm1;  // 将第一个参数放入寄存器r0
 
    // 使用svc指令触发系统调用，将结果存回reg0
    __asm__ __volatile__("svc 0" : "=r"(reg0) : "r"(reg7), "r"(reg0), "r"(reg1), "r"(reg2), "r"(reg3) : "memory");
 
    return reg0;  // 返回系统调用的结果
}
 
// 声明全局变量，用于存储单元测试的错误码和错误行号
extern INT32 g_iCunitErrCode;
extern INT32 g_iCunitErrLineNo;
 
// 声明一系列pthread相关的测试函数
extern void ItTestPthread001(void);  // pthread测试函数1
extern void ItTestPthread002(void);  // pthread测试函数2
extern void ItTestPthread003(void);  // pthread测试函数3
extern void ItTestPthread004(void);  // pthread测试函数4
extern void ItTestPthread005(void);  // pthread测试函数5
extern void ItTestPthread006(void);  // pthread测试函数6
extern void ItTestPthread007(void);  // pthread测试函数7
extern void ItTestPthread008(void);  // pthread测试函数8
extern void ItTestPthread009(void);  // pthread测试函数9
extern void ItTestPthread010(void);  // pthread测试函数10
extern void ItTestPthread012(void);  // 省略了11，可能是个错误或者遗漏
extern void ItTestPthread011(void);  // pthread测试函数11
extern void ItTestPthread013(void);  // pthread测试函数13
extern void ItTestPthread014(void);  // pthread测试函数14
extern void ItTestPthread015(void);  // pthread测试函数15
extern void ItTestPthread016(void);  // pthread测试函数16
extern void ItTestPthread017(void);  // pthread测试函数17
extern void ItTestPthread018(void);  // pthread测试函数18
extern void ItTestPthread019(void);  // pthread测试函数19
extern void ItTestPthread020(void);  // pthread测试函数20
extern void ItTestPthread021(void);  // pthread测试函数21
extern void ItTestPthread022(void);  // pthread测试函数22
extern void ItTestPthread023(void);  // pthread测试函数23
extern void ItTestPthread024(void);  // pthread测试函数24
extern void ItTestPthread025(void);  // pthread测试函数25
extern void ItTestPthread026(void);  // pthread测试函数26
extern void ItTestPthread027(void);  // pthread测试函数27
extern void ItTestPthreadAtfork001(void);  // pthread atfork测试函数1
extern void ItTestPthreadAtfork002(void);  // pthread atfork测试函数2
extern void ItTestPthreadOnce001(void);  // pthread once测试函数1
extern void ItTestPthreadCond001(void);  // pthread 条件变量测试函数1
extern void ItTestPthreadCond002(void);  // pthread 条件变量测试函数2
extern void ItTestPthreadCond003(void);  // pthread 条件变量测试函数3
extern void ItTestPthreadCond004(void);  // pthread 条件变量测试函数4
#endif  // 结束头文件保护
